/*
 * Copyright (C) 2008 Carl Worth
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/ .
 *
 * Author: Carl Worth <cworth@cworth.org>
 */

#ifndef __LOUDGAME_H__
#define __LOUDGAME_H__

#include <stdarg.h>
#include <loudmouth/loudmouth.h>

typedef struct _loudgame loudgame_t;

typedef void (*handle_message_cb) (loudgame_t	*lg,
				   const char	*peer,
				   const char	*message);

struct _loudgame {
    gchar		*server;
    gchar		*name;
    gchar		*passwd;
    LmConnection	*connection;

    GMainLoop		*main_loop;
    GHashTable		*players;

    int			 return_value;

    /* Callbacks */
    handle_message_cb	 handle_message;
};

#define LOUDGAME_HELP								\
"\tsay message         \t\tSay 'message' to everyone in the current game\n"	\
"\twhisper user message\tSay 'message' to 'user' only\n"

int
loudgame_init (loudgame_t *lg, int argc, char **argv);

int
loudgame_run (loudgame_t *lg);

void
loudgame_send (loudgame_t	*lg,
	       const char	*peer,
	       const char	*message);

void
loudgame_sendf (loudgame_t	*lg,
		const char	*peer,
		const char	*format,
		...);

void
loudgame_vsendf (loudgame_t	*lg,
		 const char	*peer,
		 const char	*format,
		 va_list	 va);

void
loudgame_broadcast (loudgame_t *lg,
		    const char *message);

void
loudgame_vbroadcastf (loudgame_t *lg,
		      const char *format,
		      va_list     va);

void
loudgame_broadcastf (loudgame_t	*lg,
		     const char	*format,
		     ...);

void
loudgame_quit (loudgame_t *lg, int return_value);

#endif /* __LOUDGAME_H__ */
